@@ -39,7 +39,7 @@ static gboolean
 cb_window_delete_event (GtkWidget *widget, GdkEvent *event, gpointer data);
 static gboolean
 cb_window_keybinding (GtkWidget *widget, GdkEventKey *event, gpointer data)
-{ 
+{
   if (event->keyval == GDK_l &&
       (event->state & (GDK_CONTROL_MASK & gtk_accelerator_get_default_mod_mask())))
     {
@@ -170,9 +170,10 @@ editor_main (GeglNode    *gegl,
   editor.graph_editor = NULL;/*gtk_label_new ("graph");*/
   editor.window = create_window (&editor);
   treeview = tree_editor_get_treeview (editor.tree_editor);
-  gtk_container_add (GTK_CONTAINER (editor.property_editor), gtk_label_new (editor.options->file));
+  gtk_container_add (GTK_CONTAINER (editor.property_editor),
+                     gtk_label_new (editor.options->file));
   gtk_widget_show (editor.window);
-  gtk_container_set_border_width (GTK_CONTAINER (editor.property_editor), 4);
+  gtk_container_set_border_width (GTK_CONTAINER (editor.property_editor), 6);
 
   editor_set_gegl (gegl);
 
@@ -240,7 +241,7 @@ static GtkActionEntry action_entries[] = {
    "Quit",
    G_CALLBACK (cb_quit_dialog)},
 
-  {"About", NULL,
+  {"About", GTK_STOCK_ABOUT,
    "_About", "",
    "About",
    G_CALLBACK (cb_about)},
@@ -256,27 +257,27 @@ static GtkActionEntry action_entries[] = {
    G_CALLBACK (cb_export)},
 
   {"ShrinkWrap", NULL,
-   "_Shrink wrap", "<control>E",
+   "_Shrink Wrap", "<control>E",
    "Size the window to the image, if feasible",
    G_CALLBACK (cb_shrinkwrap)},
 
-  {"Fit", NULL,
+  {"Fit", GTK_STOCK_ZOOM_FIT,
    "_Fit", "<control>F",
    "Fit the image in window",
    G_CALLBACK (cb_fit)},
 
   {"FitOnScreen", NULL,
-   "_Fit on screen", "",
+   "_Fit On Screen", "",
    "Fit the image on screen",
    G_CALLBACK (cb_fit_on_screen)},
 
-  {"ZoomIn", NULL,
-   "Zoom in", "<control>plus",
+  {"ZoomIn", GTK_STOCK_ZOOM_IN,
+   "Zoom In", "<control>plus",
    "",
    G_CALLBACK (cb_zoom_in)},
 
-  {"ZoomOut", NULL,
-   "Zoom out", "<control>minus",
+  {"ZoomOut", GTK_STOCK_ZOOM_OUT,
+   "Zoom Out", "<control>minus",
    "",
    G_CALLBACK (cb_zoom_out)},
 
@@ -285,7 +286,7 @@ static GtkActionEntry action_entries[] = {
    "",
    G_CALLBACK (cb_zoom_50)},
 
-  {"Zoom100", NULL,
+  {"Zoom100", GTK_STOCK_ZOOM_100,
    "100%", "<control>1",
    "",
    G_CALLBACK (cb_zoom_100)},
@@ -296,12 +297,12 @@ static GtkActionEntry action_entries[] = {
    G_CALLBACK (cb_zoom_200)},
 
   {"Recompute", NULL,
-   "_Recompute view", "<shift><control>R",
+   "_Recompute View", "<shift><control>R",
    "Recalculate all image data (for working around dirt bugs)",
    G_CALLBACK (cb_recompute)},
 
   {"Redraw", NULL,
-   "_Redraw view", "<control>R",
+   "_Redraw View", "<control>R",
    "Repaints all image data (works around display glitches)",
    G_CALLBACK (cb_redraw)},
 };
@@ -352,7 +353,7 @@ static const gchar *ui_info =
 static void cb_tree_visible (GtkAction *action, gpointer userdata);
 static void cb_properties_visible (GtkAction *action, gpointer userdata);
 static void cb_structure_visible (GtkAction *action, gpointer userdata);
-  
+
 static GtkToggleActionEntry toggle_entries[]={
     {"Tree", NULL,
      "TreeView", NULL,
@@ -418,29 +419,26 @@ cb_composition_new (GtkAction *action)
   GtkWidget *label;
   gint      result;
 
-  dialog = gtk_dialog_new_with_buttons ("GEGL - new composition",
+  dialog = gtk_dialog_new_with_buttons ("GEGL - New Composition",
                                         GTK_WINDOW (editor.window),
                                         GTK_DIALOG_MODAL,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
                                         GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                                         NULL);
+  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
-  alert =
-    StockIcon (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG,
-               editor.window);
-
-  label =
-    gtk_label_new
-    ("Discard current composition?\nAll unsaved data will be lost.");
-
-  gtk_misc_set_padding (GTK_MISC (label), 10, 10);
-
-  hbox = gtk_hbox_new (FALSE, 5);
-  gtk_container_add (GTK_CONTAINER (hbox), alert);
-  gtk_container_add (GTK_CONTAINER (hbox), label);
-
+  hbox = gtk_hbox_new (FALSE, 12);
+  gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), hbox);
 
+  alert = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
+                                    GTK_ICON_SIZE_DIALOG);
+  gtk_container_add (GTK_CONTAINER (hbox), alert);
+
+  label = gtk_label_new ("Discard current composition?\n"
+                         "All unsaved data will be lost.");
+  gtk_container_add (GTK_CONTAINER (hbox), label);
+
   gtk_widget_show_all (dialog);
   result = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -449,9 +447,9 @@ cb_composition_new (GtkAction *action)
     case GTK_RESPONSE_ACCEPT:
       {
       /* FIXME: should append to list of files, and set as current
-        editor_set_gegl (gegl_xml_parse (blank_composition), "untitled.xml");
+        editor_set_gegl (gegl_parse_xml (blank_composition), "untitled.xml");
         */
-        editor_set_gegl (gegl_xml_parse (blank_composition, "/"));
+        editor_set_gegl (gegl_parse_xml (blank_composition, "/"));
       }
       break;
     default:
@@ -473,12 +471,13 @@ cb_composition_load (GtkAction *action)
   GtkWidget *dialog;
   GtkFileFilter *filter;
 
-  dialog = gtk_file_chooser_dialog_new ("Load GEGL composition",
+  dialog = gtk_file_chooser_dialog_new ("Load GEGL Composition",
                                         GTK_WINDOW (editor.window),
                                         GTK_FILE_CHOOSER_ACTION_OPEN,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                         GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                                         NULL);
+
   filter = gtk_file_filter_new ();
   gtk_file_filter_add_mime_type (filter, "text/xml");
   gtk_file_filter_set_name (filter, "GEGL composition");
@@ -500,7 +499,7 @@ cb_composition_load (GtkAction *action)
         {
           gchar *temp = g_strdup (filename);
           gchar *path = g_strdup (dirname (temp));
-          editor_set_gegl (gegl_xml_parse (xml, path));
+          editor_set_gegl (gegl_parse_xml (xml, path));
           g_free (temp);
           g_free (path);
         }
@@ -516,7 +515,7 @@ cb_composition_save (GtkAction *action)
   GtkWidget *dialog;
   GtkFileFilter *filter;
 
-  dialog = gtk_file_chooser_dialog_new ("Save GEGL composition",
+  dialog = gtk_file_chooser_dialog_new ("Save GEGL Composition",
                                         GTK_WINDOW (editor.window),
                                         GTK_FILE_CHOOSER_ACTION_SAVE,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -590,28 +589,27 @@ cb_quit_dialog (GtkAction *action)
   GtkWidget *alert;
   gint      result;
 
-  dialog = gtk_dialog_new_with_buttons ("GEGL - quit confirmation",
+  dialog = gtk_dialog_new_with_buttons ("GEGL - Confirm Quit",
                                         GTK_WINDOW (editor.window),
                                         GTK_DIALOG_MODAL,
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
                                         GTK_STOCK_SAVE, 4,
                                         GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT,
                                         NULL);
+  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
+  hbox = gtk_hbox_new (FALSE, 12);
+  gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
+  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), hbox);
 
-  alert =
-    StockIcon (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG,
-               editor.window);
+  alert = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
+                                    GTK_ICON_SIZE_DIALOG);
+  gtk_container_add (GTK_CONTAINER (hbox), alert);
 
   label = gtk_label_new ("Really quit?\nAll unsaved data will be lost.");
-  gtk_misc_set_padding (GTK_MISC (label), 10, 10);
-
-  hbox = gtk_hbox_new (FALSE, 5);
-  gtk_container_add (GTK_CONTAINER (hbox), alert);
   gtk_container_add (GTK_CONTAINER (hbox), label);
 
   gtk_widget_show_all (hbox);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), hbox);
 
   result = gtk_dialog_run (GTK_DIALOG (dialog));
   switch (result)
@@ -648,6 +646,14 @@ static void do_load (void)
   GeglOptions *o = editor.options;
   gchar *xml = NULL;
 
+  gchar *temp1 = g_strdup (o->file);
+  gchar *temp2;
+  gchar *path_root;
+  temp2 = g_strdup (dirname (temp1));
+  path_root = g_strdup (realpath (temp2, NULL));
+  g_free (temp1);
+  g_free (temp2);
+
   if (file_is_gegl_xml (o->file))
     {
       GError      *err      = NULL;
@@ -661,14 +667,23 @@ static void do_load (void)
     {
       GString *acc = g_string_new ("");
 
-      g_string_append (acc, "<gegl><load path='");
-      g_string_append (acc, o->file);
-      g_string_append (acc, "'/></gegl>");
+            {gchar *file_basename;
+             gchar *tmp;
+             tmp=g_strdup (o->file);
+             file_basename = basename (tmp);
+
+             g_string_append (acc, "<gegl><load path='");
+             g_string_append (acc, file_basename);
+             g_string_append (acc, "'/></gegl>");
+
+             g_free (tmp);
+            }
 
       xml = g_string_free (acc, FALSE);
     }
 
-  editor_set_gegl (gegl_xml_parse (xml, "/"));
+  editor_set_gegl (gegl_parse_xml (xml, path_root));
+  g_free (path_root);
   g_free (xml);
 }
 
@@ -695,10 +710,10 @@ cb_about (GtkAction *action)
   GtkWidget *about;
   GeglNode  *gegl;
 
-  gegl = gegl_xml_parse (
-   "<gegl> <over> <invert/> <shift x='20.0' y='140.0'/> <text string=\"GEGL is a image processing and compositing framework.\n\nGUI editor Copyright © 2006 Øyvind Kolås\nGEGL and it's editor comes with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to redistribute it under certain conditions. The processing and compositing library GEGL is licensed under LGPLv2 and the editor itself is licensed as GPLv2.\" font='Sans' size='10.0' wrap='300' alignment='0' width='224' height='52'/> </over> <over> <shift x='20.0' y='10.0'/> <dropshadow opacity='1.0' x='10.0' y='10.0' radius='5.0'/> <text string='GEGL' font='Sans' size='100.0' wrap='-1' alignment='0'/> </over> <perlin-noise alpha='12.30' scale='0.10' zoff='-1.0' seed='20.0' n='6.0'/> </gegl>"
+  gegl = gegl_parse_xml (
+   "<gegl> <over> <invert/> <shift x='20.0' y='140.0'/> <text string=\"GEGL is a image processing and compositing framework.\n\nGUI editor Copyright © 2006, 2007 Øyvind Kolås\nGEGL and its editor come with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to redistribute it under certain conditions. The processing and compositing library GEGL is licensed under LGPLv2 and the editor itself is licensed as GPLv2.\" font='Sans' size='10.0' wrap='300' alignment='0' width='224' height='52'/> </over> <over> <shift x='20.0' y='10.0'/> <dropshadow opacity='1.0' x='10.0' y='10.0' radius='5.0'/> <text string='GEGL' font='Sans' size='100.0' wrap='-1' alignment='0'/> </over> <perlin-noise alpha='12.30' scale='0.10' zoff='-1.0' seed='20.0' n='6.0'/> </gegl>"
   ,NULL);
-   
+
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), "About GEGL");
   about = g_object_new (GEGL_TYPE_VIEW,
@@ -844,7 +859,7 @@ static void cb_fit_on_screen (GtkAction *action)
   {
     GdkScreen *screen= gtk_window_get_screen (GTK_WINDOW (editor.window));
 
-    gint    screen_width, screen_height;    
+    gint    screen_width, screen_height;
     gint i;
 
     screen_width = gdk_screen_get_width (screen);
@@ -870,7 +885,7 @@ static void cb_shrinkwrap (GtkAction *action)
   {
     GdkScreen *screen= gtk_window_get_screen (GTK_WINDOW (editor.window));
 
-    gint    screen_width, screen_height;    
+    gint    screen_width, screen_height;
     gint    width, height;
     gdouble scale;
     g_object_get (editor.drawing_area, "scale", &scale, NULL);
@@ -900,9 +915,11 @@ static void cb_shrinkwrap (GtkAction *action)
   }
 }
 
+void          gegl_node_disable_cache       (GeglNode      *node);
+
 static void cb_recompute (GtkAction *action)
 {
-  gegl_cache_invalidate (GEGL_VIEW(editor.drawing_area)->cache, NULL);
+  gegl_node_disable_cache (GEGL_VIEW(editor.drawing_area)->node);
   gegl_gui_flush ();
 }
 
@@ -922,7 +939,7 @@ void gegl_editor_update_title (void)
 }
 
 static void cb_zoom_100 (GtkAction *action)
-{ 
+{
   gint width, height;
   gint x,y;
   gdouble scale;
@@ -954,7 +971,7 @@ static void cb_zoom_100 (GtkAction *action)
 }
 
 static void cb_zoom_200 (GtkAction *action)
-{ 
+{
   gint width, height;
   gint x,y;
   gdouble scale;
@@ -986,7 +1003,7 @@ static void cb_zoom_200 (GtkAction *action)
 }
 
 static void cb_zoom_50 (GtkAction *action)
-{ 
+{
   gint width, height;
   gint x,y;
   gdouble scale;
@@ -1091,19 +1108,6 @@ static void cb_export (GtkAction *action)
   export_window ();
 }
 
-GtkWidget *
-StockIcon (const gchar *id, GtkIconSize size, GtkWidget *widget)
-{
-  GdkPixbuf *icon;
-  GtkWidget *image;
-
-  icon = gtk_widget_render_icon (widget, id, size, "");
-  image = gtk_image_new_from_pixbuf (icon);
-
-  g_object_unref (icon);
-  return image;
-}
-
 void editor_refresh_structure (void)
 {
   GeglStore *store = gegl_store_new ();
