@@ -43,8 +43,8 @@ static GeglRectangle get_input_rect (void)
   GeglNode *iter = gegl_node_get_output_proxy (editor.gegl, "output");
   gegl_node_get_bounding_box (editor.gegl);  /* to trigger defined setting for all */
   while (iter &&
-         gegl_node_get_connected_to (iter, "input")){
-    iter = gegl_node_get_connected_to (iter, "input");
+         gegl_node_get_producer (iter, "input", NULL)){
+    iter = gegl_node_get_producer (iter, "input", NULL);
   }
   return iter->have_rect;
 }
@@ -116,11 +116,13 @@ static void button_render_clicked (GtkButton *button,
 
   path = gtk_entry_get_text (pathe);
   
-  cache = gegl_view_get_cache (GEGL_VIEW (editor.drawing_area));
+  cache = gegl_node_get_cache (GEGL_VIEW (editor.drawing_area)->node);
 
-  gegl_cache_enqueue (cache, rect);
-
-  while (gegl_cache_render (cache));
+    {
+      gdouble progress;
+      while (gegl_cache_render (cache, &rect, &progress))
+         g_warning ("%f", progress);
+    }
 
   gegl_buffer_export_png (GEGL_BUFFER (cache),
                           &rect, path);
@@ -324,7 +326,7 @@ gegl_buffer_export_png (GeglBuffer    *gegl_buffer,
   for (i=0; i< rect->h; i++)
     {
       GeglRectangle    line = {rect->x, rect->y + i, rect->w, 1};
-      gegl_buffer_get (gegl_buffer, &line, pixels, babl_format (format_string), 1.0);
+      gegl_buffer_get (gegl_buffer, &line, 1.0, babl_format (format_string), pixels);
       png_write_rows (png, &pixels, 1);
     }
   png_write_end (png, info);
