@@ -18,88 +18,96 @@
  */
 
 
-#if 1
-#include "gegl-plugin.h"  /* is this neccesary? FIXME: should just be gegl.h
-                           
-                           gegl_node_get_connected_to
-                           gegl_node_get_operation
-                           GeglPad
-                           gegl_node_get_pad
-                           gegl_pad_get_connections
-                           GeglConnection
-                           gegl_connection_get_sink_pad
-                           gegl_pad_get_name
-                           gegl_connection_get_sink_node
-                           */
-#endif
-#if 0
-#include "gegl.h"
-#endif
-
+#include <gegl.h>
 #include "gegl-store.h"
 #include <string.h>
 
 GeglNode *gegl_children (GeglNode *item)
 {
-  return gegl_node_get_connected_to (item, "aux");
+  return gegl_node_get_producer (item, "aux", NULL);
 }
 
 GeglNode *gegl_next_sibling (GeglNode *item)
 {
   if (!strcmp (gegl_node_get_operation (item), "clone"))
     return NULL;
-  return gegl_node_get_connected_to (item, "input");
+  return gegl_node_get_producer (item, "input", NULL); /* FIXME: handle padname */
 }
 
+static GeglNode *
+node_get_consumer (GeglNode     *node,
+                   const gchar  *output_pad,
+                   gchar       **input_pad_name)
+{
+  GeglNode   **nodes = NULL;
+  GeglNode    *ret=NULL;
+  const gchar **pads;
+  gint       count = 0;
+
+  if (!node)
+    return ret;
+  count = gegl_node_get_consumers (node, output_pad, &nodes, &pads);
+  if (!count)
+    return ret;
+  g_assert (nodes);
+  g_assert (pads);
+
+  if (input_pad_name)
+    {
+      *input_pad_name = g_strdup (pads[0]);
+    }
+  ret = nodes[0];
+  g_free (nodes);
+  g_free (pads);
+  return ret;
+}
+
+
 GeglNode *gegl_previous_sibling (GeglNode *item)
 {
-  GeglPad *pad;
-  if (!item)
-    return NULL;
-
+  GeglNode *node;
+  gchar    *pad;
   
-  pad = gegl_node_get_pad (item, "output");
-  if (!pad)
-    return NULL;
+  node = node_get_consumer (item, "output", &pad);
+  if (node)
     {
-      GList *pads = gegl_pad_get_connections (pad);
-      if (pads)
+      if (strcmp (pad, "input"))
         {
-          GeglConnection *connection = pads->data;
-          GeglPad *pad = gegl_connection_get_sink_pad (connection);
-          if (!strcmp (gegl_pad_get_name (pad), "input"))
-            return gegl_connection_get_sink_node (connection);
+          /* any other node but input we're not interested in */
+          node = NULL;
         }
+      g_free (pad);
     }
-  return NULL;
+  return node;
 }
 
 GeglNode *gegl_parent (GeglNode *item)
 {
-  GeglPad *pad;
   GeglNode *iter = item;
 
   if (!item)
     return NULL;
   while (gegl_previous_sibling (iter))
     iter = gegl_previous_sibling (iter);
-
-  pad = gegl_node_get_pad (iter, "output");
-  
-  if (!pad)
+  if (!iter)
     return NULL;
-  iter = NULL;
-    {
-      GList *pads = gegl_pad_get_connections (pad);
-      if (pads)
-        {
-          GeglConnection *connection = pads->data;
-          GeglPad *pad = gegl_connection_get_sink_pad (connection);
-          if (!strcmp (gegl_pad_get_name (pad), "aux"))
-            iter = gegl_connection_get_sink_node (connection);
-        }
-    }
-  return iter;
+
+  {
+    gint n_consumers;
+    GeglNode    **nodes;
+    const gchar **pads;
+
+    n_consumers = gegl_node_get_consumers (iter, "output", &nodes, &pads);
+    if (n_consumers >0 &&
+        !strcmp (pads[0], "aux"))
+      {
+        GeglNode *ret=nodes[0];
+        g_free (nodes);
+        g_free (pads);
+        return ret;
+      }
+  }
+  return NULL;
 }
 
 /****/
