@@ -140,7 +140,7 @@ tree_editor_get_active (GtkWidget *tree_editor)
   if (!gtk_tree_selection_get_selected (tree_selection, &model, &iter))
     {
       GeglNode *proxy = gegl_node_get_output_proxy (editor.gegl, "output");
-      return gegl_node_get_connected_to (proxy, "input"); 
+      return gegl_node_get_producer (proxy, "input", NULL); 
     }
 
   item = iter.user_data;
@@ -171,7 +171,7 @@ tree_editor_set_active (GtkWidget *tree_editor, GeglNode *item)
   // gtk_tree_view_collapse_all (treeview);
   gtk_tree_view_expand_to_path (treeview, path);
   gtk_tree_selection_select_iter (tree_selection, &iter);
-  gtk_tree_view_scroll_to_cell (treeview, path, NULL, TRUE, 0, 0);
+  gtk_tree_view_scroll_to_cell (treeview, path, NULL, TRUE, 0.5, 0);
 
   gtk_tree_path_free (path);
 }
