@@ -19,6 +19,7 @@
 
 #include <glib-object.h>
 #include "gegl.h"
+#include <babl/babl.h>
 #include "gegl-view.h"
 #include "gegl-tree-editor.h"
 #include "editor.h"
@@ -110,8 +111,9 @@ gegl_view_init (GeglView *self)
   self->y           = 0;
   self->prev_x      = -1;
   self->prev_y      = -1;
-  self->dirty_rects = NULL;
   self->scale       = 1.0;
+  self->monitor_id  = 0;
+  self->processor   = NULL;
 }
 
 static void
@@ -119,49 +121,37 @@ finalize (GObject *gobject)
 {
   GeglView * self = GEGL_VIEW (gobject);
 
-  if (self->cache)
-    g_object_unref (self->cache);
   if (self->node)
     g_object_unref (self->node);
 
   G_OBJECT_CLASS (gegl_view_parent_class)->finalize (gobject);
 }
 
-static void computed_event (GeglCache *self,
-                            void           *foo,
-                            void           *user_data)
+static void computed_event (GeglNode *self,
+                            void     *foo,
+                            void     *user_data)
 {
   GeglRectangle  rect   = *(GeglRectangle*)foo;
   GeglView      *view   = GEGL_VIEW (user_data);
   GtkWidget     *widget = GTK_WIDGET (user_data);
 
-  /* FIXME: check that the area is relevant for us */
+  /* FIXME: check that the area is within this view */
 
   rect.x -= view->x;
   rect.y -= view->y;
   rect.x *= view->scale;
   rect.y *= view->scale;
-  rect.w *= view->scale;
-  rect.h *= view->scale;
-
-  if (view->scale != 1.0 &&
-      view->scale != 0.5)
-    {
-      /* Hack to avoid issues with rounding issues in redraws */
-      rect.x-=3;
-      rect.y-=3;
-      rect.w+=6;
-      rect.h+=6;
-    }
+  rect.w = ceil(view->scale * rect.w);
+  rect.h = ceil(view->scale * rect.h);
 
   gtk_widget_queue_draw_area (widget, rect.x, rect.y,
                                       rect.w, rect.h);
 }
 
 
-static void invalidated_event (GeglCache *self,
-                               void           *foo,
-                               void           *user_data)
+static void invalidated_event (GeglNode *self,
+                               void     *foo,
+                               void     *user_data)
 {
   gegl_view_repaint (GEGL_VIEW (user_data));
 }
@@ -177,22 +167,20 @@ set_property (GObject      *gobject,
   switch (property_id)
     {
     case PROP_NODE:
-      /* FIXME: a view should probably be made from a cache */
       if (self->node)
-        g_object_unref (self->node);
-      if (self->cache)
-        g_object_unref (self->cache);
+        {
+#if 0
+          gegl_node_disable_cache (self->node); /* FIXME: should we really? */
+#endif
+          g_object_unref (self->node);
+        }
       if (g_value_get_object (value))
         {
           self->node = GEGL_NODE (g_value_dup_object (value));
-          self->cache = g_object_new (GEGL_TYPE_CACHE,
-                                      "node",   self->node,
-                                      "format", babl_format ("R'G'B' u8"),
-                                      NULL);
-          g_signal_connect (G_OBJECT (self->cache), "computed",
+          g_signal_connect (G_OBJECT (self->node), "computed",
                             (GCallback)computed_event,
                             self);
-          g_signal_connect (G_OBJECT (self->cache), "invalidated",
+          g_signal_connect (G_OBJECT (self->node), "invalidated",
                             (GCallback)invalidated_event,
                             self);
           gegl_view_repaint (self);
@@ -200,7 +188,6 @@ set_property (GObject      *gobject,
       else
         {
           self->node = NULL;
-          self->cache = NULL;
         }
       break;
     case PROP_X:
@@ -213,6 +200,7 @@ set_property (GObject      *gobject,
       self->scale = g_value_get_double (value);
       break;
     default:
+
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, property_id, pspec);
       break;
     }
@@ -394,8 +382,6 @@ expose_event (GtkWidget *widget, GdkEventExpose * event)
 
   if (!view->node)
     return FALSE;
-  if (!view->cache)
-    return FALSE;
   
   gdk_region_get_rectangles (event->region, &rectangles, &count);
   
@@ -409,8 +395,15 @@ expose_event (GtkWidget *widget, GdkEventExpose * event)
 
       buf = g_malloc ((roi.w+1) * (roi.h+1) * 3);
       /* FIXME: this padding should not be needed, but it avoids some segfaults */
-      gegl_buffer_get (GEGL_BUFFER (view->cache),
-                       &roi, buf, babl_format ("R'G'B' u8"), view->scale);
+
+      gegl_node_blit (view->node,
+                      &roi,
+                      view->scale,
+                      babl_format ("R'G'B' u8"),
+                      0, /* rowstride, currently unused */
+                      (gpointer)buf,
+                      GEGL_BLIT_CACHE|GEGL_BLIT_DIRTY);
+
       gdk_draw_rgb_image (widget->window,
                           widget->style->black_gc,
                           rectangles[i].x, rectangles[i].y,
@@ -425,6 +418,20 @@ expose_event (GtkWidget *widget, GdkEventExpose * event)
   return FALSE;
 }
 
+static gboolean task_monitor (gpointer foo)
+{
+  GeglView  *view = GEGL_VIEW (foo);
+  gboolean   ret = FALSE;
+
+  ret = gegl_processor_work (view->processor, NULL);
+
+  if (ret==FALSE)
+    {
+      view->monitor_id = 0;
+    }
+  return ret;
+}
+
 void gegl_view_repaint (GeglView *view)
 {
   GtkWidget     *widget = GTK_WIDGET (view);
@@ -432,13 +439,23 @@ void gegl_view_repaint (GeglView *view)
                  widget->allocation.width / view->scale,
                  widget->allocation.height / view->scale};
 
+#if 0
   /* forget all already queued repaints */
-  gegl_cache_dequeue (view->cache, NULL);
+  gegl_cache_dequeue (gegl_node_get_cache (view->node), NULL);
   /* then enqueue our selves */
-  gegl_cache_enqueue (view->cache, roi);
-}
+  gegl_cache_enqueue (gegl_node_get_cache (view->node), roi);
+#endif
 
-GeglCache *gegl_view_get_cache (GeglView *view)
-{
-  return view->cache;
+  if (view->monitor_id == 0)
+    {
+      view->monitor_id = g_idle_add_full (
+         G_PRIORITY_LOW, (GSourceFunc) task_monitor, view, NULL);
+      if (view->processor == NULL)
+        {
+          if (view->node)
+            view->processor = gegl_node_new_processor (view->node, &roi);
+        }
+    }
+  if (view->processor)
+    gegl_processor_set_rectangle (view->processor, &roi);
 }
