@@ -389,7 +389,7 @@ gegl_buffer_constructor (GType                  type,
          buffer->abyss_height
        };
        GeglRectangle self;
-       gegl_rect_intersect (&self, &parent, &request);
+       gegl_rectangle_intersect (&self, &parent, &request);
 
        buffer->abyss_x = self.x;
        buffer->abyss_y = self.y;
@@ -764,8 +764,8 @@ gegl_buffer_iterate (GeglBuffer *buffer,
           else
             pixels = tile_width - offsetx;
 
-          if (!(buffer_x + bufx + tile_width >= buffer_abyss_x &&
-                buffer_x + bufx              <  abyss_x_total))
+          if (!(buffer_x + bufx + tile_width >=  buffer_abyss_x &&
+                buffer_x + bufx              <   abyss_x_total))
             { /* entire tile is in abyss */
               if (!write)
                 {
@@ -865,10 +865,13 @@ gegl_buffer_iterate (GeglBuffer *buffer,
 
                         {
                           gint zeros = (buffer_abyss_x) - (buffer_x + bufx);
-
                           /* left hand zeroing of abyss in tile */
-                          if (zeros > 0 && zeros < pixels)
+                          if (zeros > 0)
                             {
+                              if (zeros > pixels)
+                                zeros = pixels;
+                              if (zeros > tile_width)
+                                zeros = tile_width;
                               memset (bp, 0x00, bpx_size * zeros);
                             }
 
@@ -895,8 +898,8 @@ gegl_buffer_iterate (GeglBuffer *buffer,
 void
 gegl_buffer_set (GeglBuffer    *buffer,
                  GeglRectangle *rect,
-                 void          *src,
-                 void          *format)
+                 void          *format,
+                 void          *src)
 {
   GeglBuffer *sub_buf;
   if (format == NULL)
@@ -1010,6 +1013,8 @@ bilinear_8 (gdouble x,
 }
 #endif
 
+#if 0
+
 static inline void
 bilinear_8 (gdouble x,
             gdouble y,
@@ -1088,11 +1093,166 @@ static void resample_bilinear_u8 (void *dest_buf,
     }
 }
 
-void gegl_buffer_get (GeglBuffer    *buffer,
-                      GeglRectangle *rect,
-                      void          *dest_buf,
-                      void          *format,
-                      gdouble        scale)
+#endif
+
+static inline void
+bilinear_8 (gint    dx,
+            gint    dy,
+            guchar *src0,
+            guchar *src1,
+            guchar *src2,
+            guchar *src3,
+            guchar *dst,
+            gint    components)
+{
+#define DO_COMPONENT(iter) \
+    {\
+      gint m0, m1;\
+      m0 = ((255 - dx) * src0[iter] + dx * src1[iter])>>8;\
+      m1 = ((255 - dx) * src2[iter] + dx * src3[iter])>>8;\
+      dst[iter] = (((255 - dy) * m0 + dy * m1))>>8;\
+    }
+ 
+  switch (components)
+    {
+      case 1:
+        DO_COMPONENT(0);
+        break;
+      case 2:
+        DO_COMPONENT(0);
+        DO_COMPONENT(1);
+        break;
+      case 3:
+        DO_COMPONENT(0);
+        DO_COMPONENT(1);
+        DO_COMPONENT(2);
+        break;
+      case 4:
+        DO_COMPONENT(0);
+        DO_COMPONENT(1);
+        DO_COMPONENT(2);
+        DO_COMPONENT(3);
+        break;
+    } 
+}
+
+static void resample_bilinear_u8 (void *dest_buf,
+                                  void *source_buf,
+                                  gint  dest_w,
+                                  gint  dest_h,
+                                  gint  source_w,
+                                  gint  source_h,
+                                  gdouble scale,
+                                  gint  components)
+{
+  gint x,y;
+  gint iscale = scale * 256;
+  gint s_rowstride = source_w * components;
+  gint d_rowstride = dest_w * components;
+
+  if (components == 3)  /* optimize specially for the 3 component case since that is
+                           the normal projection and needs to be FAST
+                         */
+    {
+      for (y=0; y < dest_h; y++)
+        {
+          gint    sy;
+          gint    dy;
+          guchar *dst;
+          guchar *src_base;
+
+          sy = (y << 16) / iscale;
+
+          if (sy>=(source_h-1) << 8)
+            sy=(source_h-2) << 8;    /* is this the right thing to do? */
+
+          dy = sy & 255;
+
+          dst      = ((guchar*) dest_buf) + y * d_rowstride;
+          src_base = ((guchar*) source_buf) + (sy >> 8) * s_rowstride;
+
+          for (x=0; x < dest_w; x++)
+            {
+              gint    sx;
+              gint    dx;
+              guchar *src0;
+              guchar *src1;
+              guchar *src2;
+              guchar *src3;
+
+              sx = (x << 16) / iscale;
+
+              if (sx>=(source_w-1) << 8)  /* this check to see if we're within bounds is expensive */
+                sx=(source_w-2) << 8;    /* and the action taken might not be quite right either */
+
+              dx = sx & 255;
+
+              src0 = src_base + (sx>>8) * 3;
+              src2 = src0 + s_rowstride;
+              src1 = src0 + 3;
+              src3 = src2 + 3;
+
+              DO_COMPONENT(0)
+              DO_COMPONENT(1)
+              DO_COMPONENT(2)
+              dst += 3;
+            }
+        }
+    }
+  else
+    {
+      for (y=0; y < dest_h; y++)
+        {
+          gint    sy;
+          gint    dy;
+          guchar *dst;
+          guchar *src_base;
+
+          sy = (y << 16) / iscale;
+
+          if (sy>(source_h-1) << 8)
+            sy=(source_h-2) << 8;    /* is this the right thing to do? */
+
+          dy = sy & 255;
+
+          dst      = ((guchar*) dest_buf) + y * d_rowstride;
+          src_base = ((guchar*) source_buf) + (sy >> 8) * s_rowstride;
+
+          for (x=0; x < dest_w; x++)
+            {
+              gint    sx;
+              gint    dx;
+              guchar *src0;
+              guchar *src1;
+              guchar *src2;
+              guchar *src3;
+
+              sx = (x << 16) / iscale;
+
+              if (sx>(source_w-1) << 8)  /* this check to see if we're within bounds is expensive */
+                sx=(source_w-2) << 8;    /* and the action taken might not be quite right either */
+
+              dx = sx & 255;
+
+              src0 = src_base + (sx>>8) * components;
+              src2 = src0 + s_rowstride;
+              src1 = src0 + components;
+              src3 = src2 + components;
+
+              bilinear_8 (dx, dy, src0, src1, src2, src3, dst, components);
+              dst += components;
+            }
+        }
+    }
+}
+#undef DO_COMPONENT
+
+void
+gegl_buffer_get (GeglBuffer *buffer,
+                 GeglRectangle *rect,
+                 gdouble scale,
+                 void *format,
+                 void *dest_buf)
 {
   if (format == NULL)
     format = buffer->format;
@@ -1191,3 +1351,12 @@ void gegl_buffer_get (GeglBuffer    *buffer,
       g_free (sample_buf);
     }
 }
+
+GeglRectangle
+gegl_buffer_get_abyss (GeglBuffer *buffer)
+{
+  GeglRectangle ret={0,0,0,0};
+  gegl_rectangle_set (&ret, buffer->abyss_x, buffer->abyss_y,
+                       buffer->abyss_width, buffer->abyss_height);
+  return ret;
+}
