@@ -42,6 +42,8 @@
 #include "gegl-finish-visitor.h"
 #include "gegl-node-dynamic.h"
 #include "gegl-utils.h"
+#include "buffer/gegl-cache.h"
+#include "gegl-processor.h"
 
 
 enum
@@ -128,6 +130,17 @@ gegl_node_class_init (GeglNodeClass * klass)
       G_TYPE_NONE /* return type */,
       1 /* n_params */,
       GEGL_TYPE_RECTANGLE /* param_types */);
+
+  gegl_node_signals[GEGL_NODE_COMPUTED] =
+      g_signal_new ("computed", G_TYPE_FROM_CLASS (klass),
+      G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+      0    /* class offset*/,
+      NULL /* accumulator */,
+      NULL /* accu_data */,
+      g_cclosure_marshal_VOID__BOXED,
+      G_TYPE_NONE /* return type */,
+      1 /* n_params */,
+      GEGL_TYPE_RECTANGLE /* param_types */);
 }
 
 static void
@@ -142,6 +155,7 @@ gegl_node_init (GeglNode *self)
   self->enabled     = TRUE;
   self->is_graph    = FALSE;
   self->children    = NULL;
+  self->cache       = NULL;
 }
 
 static void
@@ -160,7 +174,15 @@ dispose (GObject *gobject)
 {
   GeglNode *self = GEGL_NODE (gobject);
 
+  if (self->parent!=NULL)
+    {
+      GeglNode *parent=self->parent;
+      self->parent=NULL;
+      gegl_node_remove_child (parent, self);
+    }
+
   gegl_node_remove_children (self);
+  gegl_node_disable_cache (self);
 
   G_OBJECT_CLASS (gegl_node_parent_class)->dispose (gobject);
 }
@@ -720,29 +742,46 @@ gegl_node_apply_roi (GeglNode      *self,
   return buffer;
 }
 
-void
-gegl_node_blit (GeglNode      *self,
-                GeglRectangle *roi,
-                void          *format,
-                gint           rowstride,
-                gpointer      *destination_buf)
+void          gegl_node_blit                (GeglNode      *node,
+                                             GeglRectangle *roi,
+                                             gdouble        scale,
+                                             void          *format,
+                                             gint           rowstride,
+                                             gpointer      *destination_buf,
+                                             GeglBlitFlags  flags)
 {
-  GeglBuffer  *buffer;
-
-  buffer = gegl_node_apply_roi (self, "output", roi);
-  {
-    GeglBuffer *roi_buf = g_object_new (GEGL_TYPE_BUFFER,
-                                        "source", buffer,
-                                        "x",      roi->x,
-                                        "y",      roi->y,
-                                        "width",  roi->w,
-                                        "height", roi->h,
-                                        NULL);
-    gegl_buffer_get (roi_buf, NULL, destination_buf, format, 1.0);
-    g_object_unref (roi_buf);
-  }
-  /* and unrefing to ultimatly clean it off from the graph */
-  g_object_unref (buffer);
+  if (flags == GEGL_BLIT_DEFAULT)
+    {
+      GeglBuffer  *buffer;
+      buffer = gegl_node_apply_roi (node, "output", roi);
+      {
+        GeglBuffer *roi_buf = g_object_new (GEGL_TYPE_BUFFER,
+                                            "source", buffer,
+                                            "x",      roi->x,
+                                            "y",      roi->y,
+                                            "width",  roi->w,
+                                            "height", roi->h,
+                                            NULL);
+        gegl_buffer_get (roi_buf, NULL, 1.0, format, destination_buf);
+        g_object_unref (roi_buf);
+        if (scale!=1.0)
+          {
+            g_warning ("Scale %f!=1.0 in blit without cache", scale);
+          }
+      }
+      /* and unrefing to ultimatly clean it off from the graph */
+      g_object_unref (buffer);
+    }
+  else if (flags & GEGL_BLIT_CACHE)
+    {
+      GeglCache *cache = gegl_node_get_cache (node);
+      if (!flags & GEGL_BLIT_DIRTY)
+        { /* if we're not blitting dirtily, we need to make sure
+             that the data is available */
+          while (gegl_cache_render (cache, roi, NULL));
+        }
+      gegl_buffer_get (GEGL_BUFFER (cache), roi, scale, format, destination_buf);
+    }
 }
 
 GeglBuffer *
@@ -783,7 +822,8 @@ gegl_node_get_depends_on (GeglNode *self)
         }
     }
 
-  if (!strcmp (gegl_object_get_name (GEGL_OBJECT (self)), "proxynop-input"))
+  if (gegl_object_get_name (GEGL_OBJECT (self)) &&
+      !strcmp (gegl_object_get_name (GEGL_OBJECT (self)), "proxynop-input"))
     {
       GeglGraph *graph = g_object_get_data (G_OBJECT (self), "graph");
       if (graph)
@@ -888,15 +928,17 @@ static void property_changed (GObject    *gobject,
   GeglNode *self = GEGL_NODE (user_data);
 
   if (self->operation &&
+      arg1!= user_data &&
       g_type_is_a (G_OBJECT_TYPE(self->operation), GEGL_TYPE_OPERATION_META))
     {
       gegl_operation_meta_property_changed (
               GEGL_OPERATION_META (self->operation), arg1, user_data);
     }
 
-  if ((arg1 &&
+  if (arg1!=user_data &&
+      ((arg1 &&
       arg1->value_type != GEGL_TYPE_BUFFER) ||
-     (self->operation && !arg1))
+     (self->operation && !arg1)))
     {
       if (self->operation && !arg1)
         { /* these means we were called due to a operation change
@@ -906,8 +948,14 @@ static void property_changed (GObject    *gobject,
              or perhaps a bug lurks here?
            */
           GeglRectangle dirty_rect;
+/*          GeglRectangle new_have_rect;*/
 
           dirty_rect = self->have_rect;
+          /*new_have_rect = gegl_node_get_bounding_box (self);
+
+          gegl_rectangle_bounding_box (&dirty_rect,
+                                       &dirty_rect,
+                                       &new_have_rect);*/
 
           g_signal_emit (self, gegl_node_signals[GEGL_NODE_INVALIDATED], 0, &dirty_rect, NULL);
         }
@@ -920,7 +968,7 @@ static void property_changed (GObject    *gobject,
           dirty_rect = self->have_rect;
           new_have_rect = gegl_node_get_bounding_box (self);
 
-          gegl_rect_bounding_box (&dirty_rect,
+          gegl_rectangle_bounding_box (&dirty_rect,
                                   &dirty_rect,
                                   &new_have_rect);
 
@@ -966,8 +1014,8 @@ gegl_node_set_operation_object (GeglNode      *self,
         pad  = gegl_connection_get_sink_pad (connection);
         output_dest_pad = g_strdup (pad->param_spec->name);
       }
-    input = gegl_node_get_connected_to (self, "input");
-    aux   = gegl_node_get_connected_to (self, "aux");
+    input = gegl_node_get_producer (self, "input", NULL);
+    aux   = gegl_node_get_producer (self, "aux", NULL);
 
     gegl_node_disconnect_sources (self);
     gegl_node_disconnect_sinks (self);
@@ -997,7 +1045,7 @@ gegl_node_set_operation_object (GeglNode      *self,
   }
 
   g_signal_connect (G_OBJECT (operation), "notify", G_CALLBACK (property_changed), self);
-  property_changed (G_OBJECT (operation), NULL, self);
+  property_changed (G_OBJECT (operation), (GParamSpec*)self, self);
 }
 
 static const gchar *
@@ -1233,21 +1281,11 @@ gegl_node_set_property (GeglNode     *self,
     }
   else
     {
-      if (self->is_graph)
+      if (self->operation)
         {
-          g_warning ("set_property for graph,. hmm");
-          /* FIXME: should this really be "input")? is_graph doesn't seem to be used,.. */
-          g_object_set_property (G_OBJECT (gegl_node_get_input_proxy (self, "input")->operation),
+          g_object_set_property (G_OBJECT (self->operation),
                 property_name, value);
         }
-      else
-        {
-          if (self->operation)
-            {
-              g_object_set_property (G_OBJECT (self->operation),
-                    property_name, value);
-            }
-        }
     }
 }
 
@@ -1412,8 +1450,9 @@ gegl_node_get_debug_name (GeglNode     *node)
 }
 
 GeglNode *
-gegl_node_get_connected_to (GeglNode *node,
-                            gchar    *pad_name)
+gegl_node_get_producer (GeglNode *node,
+                        gchar    *pad_name,
+                        gchar   **output_pad_name)
 {
   GeglPad *pad = gegl_node_get_pad (node, pad_name);
 
@@ -1423,6 +1462,11 @@ gegl_node_get_connected_to (GeglNode *node,
     {
       GeglConnection *connection = g_list_nth_data (pad->connections, 0);
 
+      if (output_pad_name)
+        {
+          GeglPad *pad= gegl_connection_get_source_pad (connection);
+          *output_pad_name = g_strdup (gegl_pad_get_name (pad));
+        }
       return gegl_connection_get_source_node (connection);
     }
   return NULL;
@@ -1431,6 +1475,7 @@ gegl_node_get_connected_to (GeglNode *node,
 GeglRectangle
 gegl_node_get_bounding_box (GeglNode     *root)
 {
+  GeglRectangle dummy={0,0,0,0};
   GeglVisitor *prepare_visitor;
   GeglVisitor *have_visitor;
   GeglVisitor *finish_visitor;
@@ -1438,11 +1483,15 @@ gegl_node_get_bounding_box (GeglNode     *root)
   gint         i;
 
   GeglPad     *pad;
+  if (!root)
+    return dummy;
   pad = gegl_node_get_pad (root, "output");
   if (pad && pad->node != root)
     {
       root = pad->node;
     }
+  if (!pad || !root)
+    return dummy;
   g_object_ref (root);
 
   for (i=0;i<2;i++)
@@ -1466,43 +1515,56 @@ gegl_node_get_bounding_box (GeglNode     *root)
   return root->have_rect; 
 }
 
-#include "gegl-operation-sink.h"
-
 void
 gegl_node_process (GeglNode *self)
 {
-  GeglNode    *input;
+  GeglProcessor *processor;
+
+  g_assert (GEGL_IS_NODE (self));
+  processor = gegl_node_new_processor (self, NULL);
+
+  while (gegl_processor_work (processor, NULL));
+  gegl_processor_destroy (processor);
+}
+
+#if 0
+/* simplest form of GeglProcess that processes all data in one
+ *
+ * single large chunk
+ */
+void
+gegl_node_process (GeglNode *self)
+{
+  GeglNode        *input;
   GeglNodeDynamic *dynamic;
-  GeglBuffer  *buffer;
-  GeglRectangle     defined;
+  GeglBuffer      *buffer;
+  GeglRectangle    defined;
 
   g_return_if_fail (GEGL_IS_NODE (self));
   g_return_if_fail (g_type_is_a (G_OBJECT_TYPE(self->operation),
                     GEGL_TYPE_OPERATION_SINK));
 
-  input = gegl_node_get_connected_to (self, "input");
+  input   = gegl_node_get_producer (self, "input", NULL);
   defined = gegl_node_get_bounding_box (input);
-  buffer = gegl_node_apply_roi (input, "output", &defined);
-
-  /*gegl_node_get (input, "output", &buffer, NULL);
-  gegl_node_set (self, "input", buffer, NULL);*/
+  buffer  = gegl_node_apply_roi (input, "output", &defined);
 
   g_assert (GEGL_IS_BUFFER (buffer));
   dynamic = gegl_node_add_dynamic (self, &defined);
 
-    {
-      GValue value = {0,};
-      g_value_init (&value, GEGL_TYPE_BUFFER);
-      g_value_set_object (&value, buffer);
-      gegl_node_dynamic_set_property (dynamic, "input", &value);
-      g_value_unset (&value);
-    }
+  {
+    GValue value = {0,};
+    g_value_init (&value, GEGL_TYPE_BUFFER);
+    g_value_set_object (&value, buffer);
+    gegl_node_dynamic_set_property (dynamic, "input", &value);
+    g_value_unset (&value);
+  }
 
   gegl_node_dynamic_set_result_rect (dynamic, defined.x, defined.y, defined.w, defined.h);
   gegl_operation_process (self->operation, &defined, "foo");
   gegl_node_remove_dynamic (self, &defined);
   g_object_unref (buffer);
 }
+#endif
 
 static gint
 lookup_dynamic (gconstpointer a,
@@ -1575,21 +1637,10 @@ gegl_node_detect (GeglNode *root,
                   gint      x,
                   gint      y)
 {
-  /*
-   *     nop
-   *      |
-   *     over
-   *     / \
-   *    in aux
-   *
-   *//*
-  g_warning ("gegl_node_detect: %i, %i", x, y);*/
-
-  /* make sure the have rects are computed */
-
-  /* FIXME: do not call this all the time! */
   if (root)
     {
+      /* make sure the have rects are computed */
+      /* FIXME: do not call this all the time! */
       gegl_node_get_bounding_box (root); 
 
       if (root->operation)
@@ -1606,3 +1657,131 @@ gegl_node_detect (GeglNode *root,
     }
   return root;
 }
+
+/* this is a bit hacky, but allows us to insert a node into the graph,
+ * and avoid the full defined region of the entire graph to change
+ */
+void
+gegl_node_insert_before (GeglNode *self,
+                         GeglNode *to_be_inserted)
+{
+  GeglNode *other = gegl_node_get_producer (self, "input", NULL); /*XXX: handle pad name */
+  GeglRectangle rectangle = gegl_node_get_bounding_box (to_be_inserted);
+
+  g_signal_handlers_block_matched (other, G_SIGNAL_MATCH_FUNC, 0, 0, 0, source_invalidated, NULL);
+  /* the blocked handler disappears during the relinking */
+  gegl_node_link_many (other, to_be_inserted, self, NULL);
+
+  /* emit the change ourselves */
+  g_signal_emit (self, gegl_node_signals[GEGL_NODE_INVALIDATED],
+                 0, &rectangle, NULL);
+}
+
+gint
+gegl_node_get_consumers (GeglNode      *node,
+                         const gchar   *output_pad,
+                         GeglNode    ***nodes,
+                         const gchar ***pads)
+{
+  GList   *connections;
+  gint     n_connections;
+  GeglPad *pad;
+  gchar  **pasp=NULL;
+
+  if (!node)
+    {
+      g_warning ("%s node==NULL", __FUNCTION__);
+      return 0;
+    }
+  
+  pad = gegl_node_get_pad (node, output_pad);
+
+  if (!pad)
+    {
+      g_warning ("%s: no such pad %s for %s", __FUNCTION__, output_pad, gegl_node_get_debug_name (node));
+      return 0;
+    }
+
+  connections = gegl_pad_get_connections (pad);
+  {
+    GList *iter;
+    gint pasp_size=0;
+    gint i;
+    gint pasp_pos=0;
+
+    n_connections = g_list_length (connections);
+    pasp_size+= (n_connections+1) * sizeof (gchar*);
+
+    for (iter=connections;iter;iter=g_list_next(iter))
+      {
+        GeglConnection *connection = iter->data;
+        GeglPad *pad = gegl_connection_get_sink_pad (connection);
+        pasp_size+=strlen (gegl_pad_get_name (pad)) + 1;
+      }
+    if (nodes)
+      *nodes = g_malloc ((n_connections + 1) * sizeof (void*));
+    if (pads)
+      {
+        pasp = g_malloc (pasp_size);
+        *pads = (void*)pasp;
+      }
+    i=0;
+    pasp_pos=(n_connections + 1) * sizeof(void*);
+    for (iter=connections;iter;iter=g_list_next(iter))
+      {
+        GeglConnection *connection = iter->data;
+        GeglPad  *pad = gegl_connection_get_sink_pad (connection);
+        GeglNode *node = gegl_connection_get_sink_node (connection);
+        const gchar *pad_name = gegl_pad_get_name (pad);
+
+        if (nodes)
+          (*nodes)[i]=node;
+        if (pasp)
+          {
+            pasp[i] = ((gchar*)pasp) + pasp_pos;
+            strcpy (pasp[i], pad_name);
+          }
+        pasp_pos += strlen (pad_name)+1;
+        i++;
+      }
+    if (nodes)
+      (*nodes)[i]=NULL;
+    if (pads)
+      pasp[i]=NULL;
+  }
+  return n_connections;
+}
+
+static void computed_event (GeglCache *self,
+                            void           *foo,
+                            void           *user_data)
+{
+  GeglNode      *node   = GEGL_NODE (user_data);
+  g_signal_emit (node, gegl_node_signals[GEGL_NODE_COMPUTED], 0, foo, NULL, NULL);
+}
+
+GeglCache *
+gegl_node_get_cache (GeglNode *node)
+{
+  if (!node->cache)
+    {
+      node->cache = g_object_new (GEGL_TYPE_CACHE,
+                                  "node", node,
+                                  "format", babl_format ("RGBA float"),
+                                  NULL);
+      g_signal_connect (G_OBJECT (node->cache), "computed",
+                        (GCallback)computed_event,
+                        node);
+    }
+  return node->cache;
+}
+
+void
+gegl_node_disable_cache (GeglNode *node)
+{
+  if (node->cache)
+    {
+      g_object_unref (node->cache);
+      node->cache = NULL;
+    }
+}
