@@ -199,7 +199,8 @@ GeglNode * gegl_operation_get_source_node (GeglOperation *operation,
 
   if (!pad)
     return NULL;
-  pad = gegl_pad_get_real_connected_to (pad);
+
+  pad = gegl_pad_get_internal_connected_to (pad);
 
   if (!pad)
     return NULL;
@@ -235,7 +236,7 @@ gegl_operation_set_source_region (GeglOperation *operation,
     GeglPad *pad = gegl_node_get_pad (operation->node, input_pad_name);
     if (!pad)
       return;
-    pad = gegl_pad_get_real_connected_to (pad);
+    pad = gegl_pad_get_internal_connected_to (pad);
     if (!pad)
       return;
     child = gegl_pad_get_node (pad);
@@ -243,7 +244,7 @@ gegl_operation_set_source_region (GeglOperation *operation,
       return;
   }
 
-  gegl_rect_bounding_box (&child_need,
+  gegl_rectangle_bounding_box (&child_need,
                           gegl_node_get_need_rect (child, context_id), region);
 
   /* expand the need rect of the node, to include what the calling
@@ -382,7 +383,7 @@ static void addop(gpointer key,
   operations_list = g_slist_prepend (operations_list, key);
 }
 
-GSList *gegl_operation_list_operations (void)
+GSList *gegl_list_operations (void)
 {
   if (!operations_list)
     {
@@ -425,7 +426,7 @@ gegl_operation_detect (GeglOperation *operation,
                        gint           x,
                        gint           y)
 {
-  GeglNode *node;
+  GeglNode *node = NULL;
   GeglOperationClass *klass;
 
   if (!operation)
@@ -437,7 +438,9 @@ gegl_operation_detect (GeglOperation *operation,
   klass = GEGL_OPERATION_GET_CLASS (operation);
 
   if (klass->detect)
-    return klass->detect (operation, x, y);
+    {
+      return klass->detect (operation, x, y);
+    }
 
   if (x>=node->have_rect.x &&
       x<node->have_rect.x+node->have_rect.w &&
