@@ -167,10 +167,28 @@ static void attach (GeglOperation *operation)
   gegl_node_connect_from (priv->output, "input", priv->load, "output");
 }
 
+static GeglNode *
+detect (GeglOperation *operation,
+        gint           x,
+        gint           y)
+{
+  GeglNode *node = operation->node;
+  Priv *priv = (Priv*)GEGL_CHANT_OPERATION (operation)->priv;
+  GeglNode *output = priv->output;
+
+  if (x >= output->have_rect.x &&
+      y >= output->have_rect.y &&
+      x  < output->have_rect.x + output->have_rect.w &&
+      y  < output->have_rect.y + output->have_rect.h)
+    return node;
+  return NULL;
+}
+
 static void class_init (GeglOperationClass *klass)
 {
   klass->prepare = prepare;
   klass->attach = attach;
+  klass->detect = detect;
   
   G_OBJECT_CLASS (klass)->dispose = dispose;
   G_OBJECT_CLASS (klass)->finalize = finalize;
@@ -209,4 +227,5 @@ refresh_cache (GeglChantOperation *self)
   return FALSE;
 }
 
+
 #endif
