@@ -139,7 +139,9 @@ get_defined_region (GeglOperation *operation)
 
       if (status)
         {
-          g_warning ("calc have rect of %s failed", self->path);
+          /* g_warning ("calc have rect of %s failed", self->path); */
+          width=10;
+          height=10;
         }
     }
   result.w = width;
@@ -318,13 +320,13 @@ gegl_buffer_import_png (GeglBuffer  *gegl_buffer,
       {
         for(i=0; i<h; i++)
           {
-            gegl_rect_set (&rect, 0, i, width, 1);
+            gegl_rectangle_set (&rect, 0, i, width, 1);
 
             if (pass != 0)
-              gegl_buffer_get (gegl_buffer, &rect, pixels, format, 1.0);
+              gegl_buffer_get (gegl_buffer, &rect, 1.0, format, pixels);
 
             png_read_rows (load_png_ptr, &pixels, NULL, 1);
-            gegl_buffer_set (gegl_buffer, &rect, pixels, format);
+            gegl_buffer_set (gegl_buffer, &rect, format, pixels);
           }
       }
   }
