@@ -110,7 +110,7 @@ get_defined_region (GeglOperation *operation)
   if (self->buf)
     {
       GeglBuffer *buffer = GEGL_BUFFER (self->buf);
-      gegl_rect_set (&result, buffer->x, buffer->y,
+      gegl_rectangle_set (&result, buffer->x, buffer->y,
                               buffer->width, buffer->height);
     }
   return result;
