@@ -132,7 +132,7 @@ op_affine_class_init (OpAffineClass *klass)
   op_class->get_defined_region  = get_defined_region;
   op_class->calc_source_regions = calc_source_regions;
   op_class->detect = detect;
-  op_class->categories = "geometry";
+  op_class->categories = "transform";
 
   filter_class->process = process;
 
@@ -448,6 +448,9 @@ calc_source_regions (GeglOperation *op,
 
   requested_rect = *(gegl_operation_get_requested_region (op, context_id));
 
+  matrix3_copy (inverse, affine->matrix);
+  matrix3_invert (inverse);
+
   if (is_intermediate_node (affine) ||
       matrix3_is_identity (inverse))
     {
